pub fn info_base_weight(req: &InfoRequest) -> u32Expand description
Classify Info requests into weight classes based on request type.
pub fn info_base_weight(req: &InfoRequest) -> u32Classify Info requests into weight classes based on request type.